@@ -61,23 +61,8 @@ hartley.test <- function (formula, data, size = "mean", alpha = 0.05, na.rm = TR
   p.value<- pmaxFratio(H.test, df, k, lower.tail = F)
   
   if (verbose) {
-    cat("\n", "", METHOD, paste("(alpha = ", alpha, ")", 
-                                sep = ""), "\n", sep = " ")
-    cat("-------------------------------------------------------------", 
-        "\n", sep = " ")
-    cat("  data :", DNAME, "\n\n", sep = " ")
-    cat("  statistic  :", H.test, "\n", sep = " ")
-    cat("  df         :", df, "\n", sep = " ")
-    
-    cat("  p.value    :", p.value, "\n\n", sep = " ")
-    cat(if (p.value > alpha) {
-      "  Result     : Variances are homogeneous."
-    }
-    else {
-      "  Result     : Variances are not homogeneous."
-    }, "\n")
-    cat("-------------------------------------------------------------", 
-        "\n\n", sep = " ")
+  print(structure(list(statistic = c("F-max" = H.test), parameter = c("df" = df), 
+                 p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
   }
   result <- list()
   result$statistic <- H.test
@@ -87,5 +72,6 @@ hartley.test <- function (formula, data, size = "mean", alpha = 0.05, na.rm = TR
   result$method <- METHOD
   result$data <- data
   result$formula <- formula
+  attr(result, "class") <- "vht"
   invisible(result)
 }
