@@ -67,23 +67,8 @@ df2 = Inf
   p.value = pf(vtest, df1, df2, lower.tail = F)
 
 if (verbose) {
-  cat("\n", "", METHOD, paste("(alpha = ", alpha, ")", 
-                              sep = ""), "\n", sep = " ")
-  cat("-------------------------------------------------------------", 
-      "\n", sep = " ")
-  cat("  data :", DNAME, "\n\n", sep = " ")
-  cat("  statistic  :", vtest, "\n", sep = " ")
-  cat("  num df     :", df1, "\n", sep = " ")
-  cat("  denom df   :", df2, "\n", sep = " ")
-  cat("  p.value    :", p.value, "\n\n", sep = " ")
-  cat(if (p.value > alpha) {
-    "  Result     : Variances are homogeneous."
-  }
-  else {
-    "  Result     : Variances are not homogeneous."
-  }, "\n")
-  cat("-------------------------------------------------------------", 
-      "\n\n", sep = " ")
+  print(structure(list(statistic = c("F" = vtest), parameter = c("num df" = df1, "denom df" = df2), 
+                 p.value = p.value, method = METHOD, data.name = DNAME), class = "htest"))
 }
 result <- list()
 result$statistic <- vtest
@@ -93,5 +78,6 @@ result$alpha <- alpha
 result$method <- METHOD
 result$data <- data
 result$formula <- formula
+attr(result, "class") <- "vht"
 invisible(result)
 }
